==> 0.6.2.tar.gz: lib/attestr_flowx.dart <==
import 'attestr_flowx_platform_interface.dart';
import 'package:eventify/eventify.dart';
import 'package:flutter/services.dart';


/**
 * Copyright (c) 2022 Pegadroid IQ Solutions Pvt. Ltd.
 *
 * @Author Attestr Developer
 * @Since 09/06/22
 **/

/// AttestrFlowx plugin for Flutter
class AttestrFlowx {

  static const MethodChannel platform = MethodChannel('attestr_flowx_plugin');
  late EventEmitter _eventEmitter;
  // Response codes from platform
  static const _CODE_FLOW_COMPLETE = 0;
  static const _CODE_FLOW_SKIP = 1;
  static const _CODE_FLOW_ERROR = 2;

  // Event names
  static const EVENT_FLOW_COMPLETE = 'FlowxSuccess';
  static const EVENT_FLOW_SKIP = 'FlowxSkip';
  static const EVENT_FLOW_ERROR = 'FlowxError';

  // Flow error codes
  static const _INVALID_PARAMETERS = 3;

  AttestrFlowx() {
    _eventEmitter = EventEmitter();
  }

  /// Use this function to launch the Attestr flow
  /// [params] Should contain hs, cl, lc, retry and qr
  void initiateSession(Map<String, dynamic> params) async {
    try {
      Map<dynamic, dynamic> validationParameters = _validateParameters(params);
      if (!validationParameters['success']) {
        Map<dynamic, dynamic> exceptionMap = {
          'type': _CODE_FLOW_ERROR,
          'message': {
            'code': _INVALID_PARAMETERS,
            'message': "Invalid parameters hs & cl "
          }
        };
        _handleResult(exceptionMap);
        return;
      }
      var result = await platform.invokeMethod(
          'initiateSession',
          params
      );
      _handleResult(result);
    } on PlatformException catch (e) {
      Map<dynamic, dynamic> exceptionMap = {
        'type': _CODE_FLOW_ERROR,
        'message': {
          'code': 5001,
          'httpStatusCode': 500,
          'message': "Request could not be processed"
        }
      };
      _handleResult(exceptionMap);
    }

  }

  void _handleResult(Map<dynamic, dynamic> response) {
    switch (response['type']) {
      case _CODE_FLOW_COMPLETE:
        _eventEmitter.emit(EVENT_FLOW_COMPLETE, null, response['message']);
        break;
      case _CODE_FLOW_SKIP:
        _eventEmitter.emit(EVENT_FLOW_SKIP , null, response['message']);
        break;
      case _CODE_FLOW_ERROR:
        _eventEmitter.emit(EVENT_FLOW_ERROR, null, response['message']);
        break;
    }
  }

  /// Registers event listeners
  /// Define your success, error and skip handler
  void on(String event, Function handler) {
    EventCallback cb = (event, cont) {
      handler(event.eventData);
    };
    _eventEmitter.on(event, null, cb);
  }

  // Clears all event listeners
  void clear() {
    _eventEmitter.clear();
  }

  Map<dynamic, dynamic> _validateParameters(Map<dynamic, dynamic> params) {
    String handshakeID = params['hs'];
    String clientKey = params['cl'];
    if (handshakeID.isEmpty && clientKey.isEmpty ||
    handshakeID == null && clientKey == null) {
      return {
        'success': false
      };
    }
    return {'success': true};
  }

  Future<String?> getPlatformVersion() {
    return AttestrFlowxPlatform.instance.getPlatformVersion();
  }

}

==> 0.6.3.tar.gz: lib/attestr_flowx.dart <==
import 'attestr_flowx_platform_interface.dart';
import 'package:eventify/eventify.dart';
import 'package:flutter/services.dart';


/**
 * Copyright (c) 2022 Pegadroid IQ Solutions Pvt. Ltd.
 *
 * @Author Attestr Developer
 * @Since 09/06/22
 **/

/// AttestrFlowx plugin for Flutter
class AttestrFlowx {

  static const MethodChannel platform = MethodChannel('attestr_flowx_plugin');
  late EventEmitter _eventEmitter;
  // Response codes from platform
  static const _CODE_FLOW_COMPLETE = 0;
  static const _CODE_FLOW_SKIP = 1;
  static const _CODE_FLOW_ERROR = 2;

  // Event names
  static const EVENT_FLOW_COMPLETE = 'FlowxSuccess';
  static const EVENT_FLOW_SKIP = 'FlowxSkip';
  static const EVENT_FLOW_ERROR = 'FlowxError';

  // Flow error codes
  static const _INVALID_PARAMETERS = 3;

  AttestrFlowx() {
    _eventEmitter = EventEmitter();
  }

  /// Use this function to launch the Attestr flow
  /// [params] Should contain hs, cl, lc, retry and qr
  void initiateSession(Map<String, dynamic> params) async {
    try {
      Map<dynamic, dynamic> validationParameters = _validateParameters(params);
      if (!validationParameters['success']) {
        Map<dynamic, dynamic> exceptionMap = {
          'type': _CODE_FLOW_ERROR,
          'message': {
            'code': _INVALID_PARAMETERS,
            'message': "Invalid parameters hs & cl "
          }
        };
        _handleResult(exceptionMap);
        return;
      }
      var result = await platform.invokeMethod(
          'initiateSession',
          params
      );
      _handleResult(result);
    } on PlatformException catch (e) {
      print("PlatformException: ${e.toString()}");
      Map<dynamic, dynamic> exceptionMap = {
        'type': _CODE_FLOW_ERROR,
        'message': {
          'code': 5001,
          'httpStatusCode': 500,
          'message': "Request could not be processed"
        }
      };
      _handleResult(exceptionMap);
    }

  }

  void _handleResult(Map<dynamic, dynamic> response) {
    switch (response['type']) {
      case _CODE_FLOW_COMPLETE:
        _eventEmitter.emit(EVENT_FLOW_COMPLETE, null, response['message']);
        break;
      case _CODE_FLOW_SKIP:
        _eventEmitter.emit(EVENT_FLOW_SKIP , null, response['message']);
        break;
      case _CODE_FLOW_ERROR:
        _eventEmitter.emit(EVENT_FLOW_ERROR, null, response['message']);
        break;
    }
  }

  /// Registers event listeners
  /// Define your success, error and skip handler
  void on(String event, Function handler) {
    EventCallback cb = (event, cont) {
      handler(event.eventData);
    };
    _eventEmitter.on(event, null, cb);
  }

  // Clears all event listeners
  void clear() {
    _eventEmitter.clear();
  }

  Map<dynamic, dynamic> _validateParameters(Map<dynamic, dynamic> params) {
    String handshakeID = params['hs'];
    String clientKey = params['cl'];
    if (handshakeID.isEmpty && clientKey.isEmpty) {
      return {
        'success': false
      };
    }
    return {'success': true};
  }

  Future<String?> getPlatformVersion() {
    return AttestrFlowxPlatform.instance.getPlatformVersion();
  }

}
